### Name: AR
### Title: (Adjusted) Attributable Risk Estimates, Variances and Confidence
###   Intervals
### Aliases: AR
### Keywords: manip

### ** Examples

data(icu)
attach(data.frame(icu))

### Computation of crude AR for INF model-free and ###
###  model-based with variance estimates ###
Exp <- matrix(INF,ncol=1)
colnames(Exp) <- "Infection"
AR(D = STA, x = Exp, Var = "delta")
AR(D = STA, x = Exp, model = TRUE, fmla = "STA~Infection", Var="delta")

### Computation of adjusted AR model-free adjusted for SEX and RACE ###
### First coerce variable RACE into dummy matrix as it is not dichotomous! ###
RACENEW <- model.matrix(~as.factor(RACE)-1)
AR(D = STA, x = Exp, C = cbind(SEX,RACENEW), Var="delta", CI="normal") 

### Computation of joint attributable risk for exposure factors INF and TYP ###
### adjusted for RACE and SEX ###
Exp2 <- cbind(INF,TYP)
Conf <- cbind(RACENEW,SEX)
AR(D = STA, x = Exp2, C = Conf, Var="delta")

### Computation of model-based AR for the exposure factor INF, ###\n
### adjusted for TYP, LOC and SEX ###
Conf <- cbind(RACENEW[,-3],SEX)
colnames(Conf) <- c("white","black","sex")
AR(D = STA, x = Exp, C = Conf, model = TRUE, 
    fmla = "STA~Infection+white+black+sex", Var = "delta", CI = "normal")



